# Setup

## PDM for Dependency Management

We use [pdm](https://pdm-project.org/en/latest/) for cross-platform dependency management. Follow the [instructions](https://pdm-project.org/en/latest/#installation) to install. 

## Pre-commit hooks

Ensure pre-commit hooks are installed
``` bash
pdm run pre-commit install
```